@@ -1,5 +1,4 @@
-from pydoc import cli
-from RSTAB.initModel import Model, clearAttributes, ConvertToDlString
+from RSTAB.initModel import Model, clearAttributes, deleteEmptyAttributes, ConvertToDlString
 from RSTAB.enums import ImperfectionType, ImperfectionCaseDirection, DirectionForLevelDirection
 from RSTAB.enums import ImperfectionCaseSourceType, ImperfectionCaseAssignmentType
 
@@ -67,6 +66,9 @@ class ImperfectionCase():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Imperfection Case to client model
         model.clientModel.service.set_imperfection_case(clientObject)
 
@@ -124,6 +126,9 @@ class ImperfectionCase():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Imperfection Case to client model
         model.clientModel.service.set_imperfection_case(clientObject)
 
@@ -222,6 +227,9 @@ class ImperfectionCase():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Imperfection Case to client model
         model.clientModel.service.set_imperfection_case(clientObject)
 
@@ -288,6 +296,9 @@ class ImperfectionCase():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Imperfection Case to client model
         model.clientModel.service.set_imperfection_case(clientObject)
 
@@ -388,6 +399,9 @@ class ImperfectionCase():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Imperfection Case to client model
         model.clientModel.service.set_imperfection_case(clientObject)
 
@@ -464,5 +478,8 @@ class ImperfectionCase():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Imperfection Case to client model
         model.clientModel.service.set_imperfection_case(clientObject)
