@@ -1,4 +1,4 @@
-from RSTAB.initModel import Model, clearAttributes
+from RSTAB.initModel import Model, clearAttributes, deleteEmptyAttributes
 
 class ResultCombination():
 
@@ -33,5 +33,8 @@ class ResultCombination():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Result Combination to client model
         model.clientModel.service.set_result_combination(clientObject)
