@@ -1,4 +1,4 @@
-from RSTAB.initModel import Model, clearAttributes
+from RSTAB.initModel import Model, clearAttributes, deleteEmptyAttributes
 from RSTAB.enums import StabilityAnalysisSettingsAnalysisType
 from RSTAB.enums import StabilityAnalysisSettingsEigenvalueMethod
 from RSTAB.enums import StabilityAnalysisSettingsMatrixType
@@ -41,7 +41,7 @@ class StabilityAnalysisSettings():
         clientObject.number_of_lowest_eigenvalues = 4
 
         # Eigenvalue Method
-        clientObject.eigenvalue_method = StabilityAnalysisSettingsEigenvalueMethod.EIGENVALUE_METHOD_LANCZOS.name
+        clientObject.eigenvalue_method = StabilityAnalysisSettingsEigenvalueMethod.EIGENVALUE_METHOD_SUBSPACE_ITERATION.name
 
         # Matrix Type
         clientObject.matrix_type = StabilityAnalysisSettingsMatrixType.MATRIX_TYPE_STANDARD.name
@@ -54,6 +54,9 @@ class StabilityAnalysisSettings():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Stability Analysis Settings to client model
         model.clientModel.service.set_stability_analysis_settings(clientObject)
 
@@ -66,7 +69,7 @@ class StabilityAnalysisSettings():
                  critical_load_factor = None,
                  minimum_initial_strain = 1e-05,
                  local_torsional_rotations = None,
-                 eigenvalue_method = StabilityAnalysisSettingsEigenvalueMethod.EIGENVALUE_METHOD_LANCZOS,
+                 eigenvalue_method = StabilityAnalysisSettingsEigenvalueMethod.EIGENVALUE_METHOD_SUBSPACE_ITERATION,
                  matrix_type = StabilityAnalysisSettingsMatrixType.MATRIX_TYPE_STANDARD,
                  comment: str = '',
                  params: dict = None,
@@ -151,6 +154,9 @@ class StabilityAnalysisSettings():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Stability Analysis Settings to client model
         model.clientModel.service.set_stability_analysis_settings(clientObject)
 
@@ -166,7 +172,7 @@ class StabilityAnalysisSettings():
                  incrementally_increasing_loading = [1.0, 0.1, 10, 100],
                  stopping_of_load_increasing = None,
                  save_results_of_all_increments: bool = False,
-                 eigenvalue_method = StabilityAnalysisSettingsEigenvalueMethod.EIGENVALUE_METHOD_LANCZOS,
+                 eigenvalue_method = StabilityAnalysisSettingsEigenvalueMethod.EIGENVALUE_METHOD_SUBSPACE_ITERATION,
                  matrix_type = StabilityAnalysisSettingsMatrixType.MATRIX_TYPE_STANDARD,
                  comment: str = '',
                  params: dict = None,
@@ -261,7 +267,7 @@ class StabilityAnalysisSettings():
 
         # Increase Loading
         if len(incrementally_increasing_loading) != 4:
-            raise Exception('WARNING: The incrementally increasing loading parameter needs to be of length 4. Kindly check list inputs for completeness and correctness.')
+            raise ValueError('WARNING: The incrementally increasing loading parameter needs to be of length 4. Kindly check list inputs for completeness and correctness.')
         clientObject.initial_load_factor = incrementally_increasing_loading[0]
         clientObject.load_factor_increment = incrementally_increasing_loading[1]
         clientObject.refinement_of_the_last_load_increment = incrementally_increasing_loading[2]
@@ -270,7 +276,7 @@ class StabilityAnalysisSettings():
         # Stopping of Load-Increasing
         if stopping_of_load_increasing:
             if len(stopping_of_load_increasing) != 3:
-                raise Exception('WARNING: For active stopping of load-increasing, the stopping of load increasing parameter needs to be of length 3. Kindly check list inputs for completeness and correctness.')
+                raise ValueError('WARNING: For active stopping of load-increasing, the stopping of load increasing parameter needs to be of length 3. Kindly check list inputs for completeness and correctness.')
             clientObject.activate_stopping_of_load_increasing = True
             clientObject.stopping_of_load_increasing_result = stopping_of_load_increasing[0].name
             if stopping_of_load_increasing[0].name == 'RESULT_TYPE_DISPLACEMENT_U' or stopping_of_load_increasing[0].name == 'RESULT_TYPE_DISPLACEMENT_U_X' or stopping_of_load_increasing[0].name == 'RESULT_TYPE_DISPLACEMENT_U_Y' or stopping_of_load_increasing[0].name == 'RESULT_TYPE_DISPLACEMENT_U_Z':
@@ -296,6 +302,9 @@ class StabilityAnalysisSettings():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Stability Analysis Settings to client model
         model.clientModel.service.set_stability_analysis_settings(clientObject)
 
@@ -381,7 +390,7 @@ class StabilityAnalysisSettings():
 
         # Increase Loading
         if len(incrementally_increasing_loading) != 4:
-            raise Exception('WARNING: The incrementally increasing loading parameter needs to be of length 4. Kindly check list inputs for completeness and correctness.')
+            raise ValueError('WARNING: The incrementally increasing loading parameter needs to be of length 4. Kindly check list inputs for completeness and correctness.')
         clientObject.initial_load_factor = incrementally_increasing_loading[0]
         clientObject.load_factor_increment = incrementally_increasing_loading[1]
         clientObject.refinement_of_the_last_load_increment = incrementally_increasing_loading[2]
@@ -390,7 +399,7 @@ class StabilityAnalysisSettings():
         # Stopping of Load-Increasing
         if stopping_of_load_increasing:
             if len(stopping_of_load_increasing) != 3:
-                raise Exception('WARNING: For active stopping of load-increasing, the stopping of load increasing parameter needs to be of length 3. Kindly check list inputs for completeness and correctness.')
+                raise ValueError('WARNING: For active stopping of load-increasing, the stopping of load increasing parameter needs to be of length 3. Kindly check list inputs for completeness and correctness.')
             clientObject.activate_stopping_of_load_increasing = True
             clientObject.stopping_of_load_increasing_result = stopping_of_load_increasing[0].name
             if stopping_of_load_increasing[0].name == 'RESULT_TYPE_DISPLACEMENT_U' or stopping_of_load_increasing[0].name == 'RESULT_TYPE_DISPLACEMENT_U_X' or stopping_of_load_increasing[0].name == 'RESULT_TYPE_DISPLACEMENT_U_Y' or stopping_of_load_increasing[0].name == 'RESULT_TYPE_DISPLACEMENT_U_Z':
@@ -410,5 +419,8 @@ class StabilityAnalysisSettings():
             for key in params:
                 clientObject[key] = params[key]
 
+        # Delete None attributes for improved performance
+        deleteEmptyAttributes(clientObject)
+
         # Add Stability Analysis Settings to client model
         model.clientModel.service.set_stability_analysis_settings(clientObject)
