@@ -1,5 +1,7 @@
+import os
 import sys
 import RSTAB.dependencies
+import socket
 import requests
 from suds.client import Client
 from RSTAB.enums import ObjectTypes, ModelType, AddOn
@@ -9,8 +11,31 @@ from RSTAB.suds_requests import RequestsTransport
 # Check server port range set in "Program Options & Settings"
 # By default range is set between 8081 ... 8089
 print('Connecting to server...')
+
+# local machine url format: 'http://127.0.0.1'
+url = 'http://127.0.0.1'
+# port format: '8081'
+port = '8081'
+urlAndPort = url+':'+port
+
+# Check if port is listening
+a_socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+
+location = (url[7:], int(port))
+result_of_check = a_socket.connect_ex(location)
+
+if result_of_check == 0:
+    a_socket.close()
+else:
+    print('Error: Port '+urlAndPort+' is not open.')
+    print('Please check:')
+    print('- If you have started RSTAB application at the remote destination correctly.')
+    a_socket.close()
+    sys.exit()
+
+# Check for issues locally and remotely
 try:
-    client = Client('http://localhost:8081/wsdl')
+    client = Client(urlAndPort+'/wsdl', location = urlAndPort)
 except:
     print('Error: Connection to server failed!')
     print('Please check:')
@@ -19,6 +44,8 @@ except:
     print('- If server port range is set correctly')
     print('- If you have a valid Web Services license')
     print('- Check Program Options & Settings > Web Services')
+    print('On remote PC please check:')
+    print('- If the firewall enables you to listen to selected port.')
     sys.exit()
 
 try:
@@ -32,7 +59,7 @@ except:
 # Next 4 lines enables Client to work within 1 session which is much faster to execute.
 # Without it the session lasts only one request which results in poor performance.
 # Assigning session to application Client (here client) instead of model Client
-# results also in poor performace.
+# results also in poor performance.
 session = requests.Session()
 adapter = requests.adapters.HTTPAdapter(pool_connections=1, pool_maxsize=1)
 session.mount('http://', adapter)
@@ -40,8 +67,7 @@ trans = RequestsTransport(session)
 
 class Model():
     clientModel = None
-    clientModelLst = []
-    activeSession = False
+    clientModelDct = {}
 
     def __init__(self,
                  new_model: bool=True,
@@ -61,40 +87,63 @@ class Model():
         """
 
         cModel = None
-        modelLs = client.service.get_model_list()
+        modelLst = []
+        modelVct = client.service.get_model_list()
+        if modelVct:
+            modelLst = modelVct.name
+
+        # The model suffix is omitted in modelLs, so it must be omitted in model_name to match exactly
+        original_model_name = model_name
+        if '.rs9' in model_name:
+            model_name = model_name[:-4]
 
         if new_model:
-            if modelLs and model_name in modelLs.name:
-                modelIndex = 0
-                for i,j in enumerate(modelLs.name):
-                    if modelLs.name[i] == model_name:
-                        modelIndex = i
-                new = client.service.get_model(modelIndex) + 'wsdl'
-                # Set transport parameter if it is the first model
-                if Model.activeSession:
-                    cModel = Client(new)
-                else:
-                    cModel = Client(new, transport=trans)
+            # Requested new model but the model with given name was already connected
+            if model_name in self.clientModelDct:
+                cModel = self.clientModelDct[model_name]
                 cModel.service.delete_all_results()
                 cModel.service.delete_all()
+
+            # Requested new model, model with given name DOESN'T exist yet
             else:
-                new = client.service.new_model(model_name) + 'wsdl'
-                if Model.activeSession:
-                    cModel = Client(new)
+                modelPath = ''
+                # Requested new model, model with given name was NOT connected yet but file with the same name was opened
+                if model_name in modelLst:
+                    id = 0
+                    for i,j in enumerate(modelLst):
+                        if modelLst[i] == model_name:
+                            id = i
+                    modelPath =  client.service.get_model(id)
                 else:
-                    cModel = Client(new, transport=trans)
-                if not modelLs:
-                    Model.activeSession = True
+                    modelPath =  client.service.new_model(original_model_name)
+                modelPort = modelPath[-5:-1]
+                modelUrlPort = url+':'+modelPort
+                modelCompletePath = modelUrlPort+'/wsdl'
+
+                if self.clientModelDct:
+                    cModel = Client(modelCompletePath, location = modelUrlPort)
+                else:
+                    cModel = Client(modelCompletePath, transport=trans, location = modelUrlPort)
+                self.clientModelDct[model_name] = cModel
+
         else:
-            modelIndex = 0
-            for i,j in enumerate(modelLs.name):
-                if modelLs.name[i] == model_name:
-                    modelIndex = i
-            new = client.service.get_model(modelIndex) + 'wsdl'
-            if Model.activeSession:
-                cModel = Client(new)
+            # Requested model which was already connected
+            assert model_name in self.clientModelDct or model_name in modelLst, 'WARNING: '+model_name +'is not connected neither opened in RSTAB.'
+
+            if model_name in self.clientModelDct:
+                cModel = self.clientModelDct[model_name]
             else:
-                cModel = Client(new, transport=trans)
+                id = 0
+                for i,j in enumerate(modelLst):
+                    if modelLst[i] == model_name:
+                        id = i
+                modelPath =  client.service.get_model(id)
+                modelPort = modelPath[-5:-1]
+                modelUrlPort = url+':'+modelPort
+                modelCompletePath = modelUrlPort+'/wsdl'
+                cModel = Client(modelCompletePath, location = modelUrlPort)
+                self.clientModelDct[model_name] = cModel
+
             if delete:
                 print('Deleting results...')
                 cModel.service.delete_all_results()
@@ -102,21 +151,37 @@ class Model():
                 print('Delete all...')
                 cModel.service.delete_all()
 
-        # when using multiple intances/model
+        # when using multiple instances/model
         self.clientModel = cModel
-        if not modelLs or not model_name in modelLs.name:
-            Model.clientModelLst.append(cModel)
-        # when using only one instace/model
+        # when using only one instance/model
         Model.clientModel = cModel
 
+    def __delete__(self, index_or_name):
+        '''
+        Purpose of this function is to facilitate removing client instances
+        from clientModelDct dictionary, which is held in Model for the purpose of
+        working with mustiple models either created directly in RSTAB or opened from file.
 
-    def __delete__(self, index):
-        if len(self.clientModelLst) == 1:
-            self.clientModelLst.clear()
-            self.clientModel = None
-        else:
-            self.clientModelLst.pop(index)
-            self.clientModel = self.clientModelLst[-1]
+        Args:
+            index_or_name (str or int): Name of the index of model
+        '''
+        if isinstance(index_or_name, str):
+            self.clientModelDct.pop(index_or_name)
+            if len(self.clientModelDct) > 0:
+                model_key = list(self.clientModelDct)[-1]
+                self.clientModel = self.clientModelDct[model_key]
+            else:
+                self.clientModel = None
+        if isinstance(index_or_name, int):
+            assert index_or_name <= len(self.clientModelDct)
+            modelLs = client.service.get_model_list()
+            self.clientModelDct.pop(modelLs.name[index_or_name])
+            if len(self.clientModelDct) > 0:
+                model_key = list(self.clientModelDct)[-1]
+                self.clientModel = self.clientModelDct[model_key]
+
+            else:
+                self.clientModel = None
 
 def clearAttributes(obj):
     '''
@@ -133,26 +198,80 @@ def clearAttributes(obj):
         obj[i[0]] = None
     return obj
 
+def deleteEmptyAttributes(obj):
+    '''
+    Delete all attributes that are None for better performance.
+
+    Args:
+        obj: object to clear
+    '''
+
+    # iterator
+    it = iter(obj)
+    for i in it:
+        if obj[i[0]] is None:
+            delattr(obj, i[0])
+    return obj
+
+def openFile(model_path):
+    '''
+    Open file with a name.
+    This routine primarily adds client instance into
+    Model.clientModelLst which manages all connections to the models.
+    New Model class instance is invoked.
+    It should be used when opening a file.
+
+    Args:
+        model_path (str): Path to RSTAB9 model.
+    Returns:
+        model (client instance): RSTAB model instance
+    '''
+    assert os.path.exists(model_path)
+
+    file_name = os.path.basename(model_path)
+    client.service.open_model(model_path)
+    return Model(True, file_name)
+
 def closeModel(index_or_name, save_changes = False):
-    """
-    Close any model with index or name. Be sure to close the first created
-    model last (2,1, and then 0). 0 index carries whole session.
+    '''
+    Close any model connected to client with index or name.
+    Make sure to close the first open model last.
+    First model carries whole session (locking of the RSTAB).
 
     Args:
         index_or_name : Model Index or Name to be Close
-        save_changes (bool): Enable/Diable Save Changes Option
-    """
+        save_changes (bool): Enable/Disable Save Changes Option
+    '''
     if isinstance(index_or_name, int):
-        client.service.close_model(index_or_name, save_changes)
         Model.__delete__(Model, index_or_name)
+        client.service.close_model(index_or_name, save_changes)
+
     elif isinstance(index_or_name, str):
+        if '.rs9' in index_or_name:
+            index_or_name = index_or_name[:-4]
+
         modelLs = client.service.get_model_list()
         for i,j in enumerate(modelLs.name):
             if modelLs.name[i] == index_or_name:
+                Model.__delete__(Model, index_or_name)
                 client.service.close_model(i, save_changes)
+                continue
     else:
         assert False, 'Parameter index_or_name must be int or string.'
 
+def saveFile(model_path):
+    '''
+    This function saves a model in a .rs9 file.
+
+    Args:
+        index_or_name : Model Index or Name to be Close
+        model_path: Path to RSTAB9 model.
+    '''
+    if model_path[len(model_path) - 4:len(model_path)].lower() != '.rs9':
+        model_path = model_path + '.rs9'
+
+    Model.clientModel.service.save(model_path)
+
 def insertSpaces(lst: list):
     '''
     Add spaces between list of numbers.
@@ -164,7 +283,7 @@ def Calculate_all(generateXmlSolverInput: bool = False, model = Model):
     '''
     Calculates model.
     CAUTION: Don't use it in unit tests!
-    It works when executing tests individualy but when running all of them
+    It works when executing tests individually but when running all of them
     it causes RSTAB to stuck and generates failures, which are hard to investigate.
 
     Args:
@@ -239,7 +358,7 @@ def ConvertStrToListOfInt(st):
 
 def CheckIfMethodOrTypeExists(modelClient, method_or_type, unitTestMode=False):
     """
-    Check if SOAP method or type is present in your version of RSTAB/RSTAB.
+    Check if SOAP method or type is present in your version of RSTAB.
     Use it only in your examples.
     Unit tests except msg from SUDS where this is checked already.
 
@@ -269,11 +388,11 @@ def CheckIfMethodOrTypeExists(modelClient, method_or_type, unitTestMode=False):
 def GetAddonStatus(modelClient, addOn = AddOn.stress_analysis_active):
     """
     Check if Add-on is reachable and active.
-    For some types of objects, specific Add-ons need to be ennabled.
+    For some types of objects, specific Add-ons need to be enabled.
 
     Args:
         modelClient (Model.clientModel)
-        addOn (enum): AddOn Enumeraion
+        addOn (enum): AddOn Enumeration
 
     Returns:
         (bool): Status of Add-on
@@ -302,11 +421,11 @@ def GetAddonStatus(modelClient, addOn = AddOn.stress_analysis_active):
 def SetAddonStatus(modelClient, addOn = AddOn.stress_analysis_active, status = True):
     """
     Activate or deactivate Add-on.
-    For some types of objects, specific Add-ons need to be ennabled.
+    For some types of objects, specific Add-ons need to be enabled.
 
     Args:
         modelClient (Model.clientModel)
-        addOn (enum): AddOn Enumeraion
+        addOn (enum): AddOn Enumeration
         status (bool): in/active
 
     Analysis addOns list:
@@ -357,7 +476,7 @@ def SetAddonStatus(modelClient, addOn = AddOn.stress_analysis_active, status = T
 
 def CalculateSelectedCases(loadCases: list = None, designSituations: list = None, loadCombinations: list = None, model = Model):
     '''
-    This method calculate just selected objects - load cases, desingSituations, loadCombinations
+    This method calculate just selected objects - load cases, designSituations, loadCombinations
 
     Args:
         loadCases (list, optional): Load Case List
